@@ -20,9 +20,9 @@ from django.conf import settings
 from django.contrib import messages
 from django.core.paginator import EmptyPage
 from django.core.paginator import Paginator
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.dateparse import parse_datetime
 from django.utils.translation import ugettext as _  # noqa
 from django.utils.translation import ugettext_lazy
@@ -163,7 +163,7 @@ class AlarmServiceView(tables.DataTableView):
                 try:
                     if self.service[:3] == 'b64':
                         name, value = self.service.split(":")
-                        self.service = base64.urlsafe_b64decode(str(value))
+                        self.service = base64.urlsafe_b64decode(str(value)).decode('utf-8')
                     results = api.monitor.alarm_list_by_dimension(self.request,
                                                                   self.service,
                                                                   page_offset,
